/***************************************************************************//**
* \file main.c
* \version 1.0
*
* \brief
* Demonstrates blinking an LED under firmware control. The Cortex-M4 toggles
* the Red LED. The Cortex-M0+ starts the Cortex-M4 and enters sleep.
*
* Compatible Kits:
*   CY8CKIT-062-BLE
*   CY8CKIT-062-WIFI-BT
*
* Migration to CY8CPROTO-062-4343W kit (ModusToolbox IDE):
*   1. Create this project targeting the CY8CPROTO-062-4343W kit.
*   2. Open design.modus file and replicate P0[3] configuration on P13[7]. Give
*      this pin the alias "LED_RED". Disable P0[3].
*   3. Build and Program
* 
* Migration to CY8CPROTO-062-4343W kit (command line make):
*   1. Launch the Device Configurator tool from 
*      ModusToolbox_1.0\tools\device-configurator-1.0\
*   2. In Device Configurator, open design.modus file  
*      (ModusToolbox_1.0\libraries\psoc6sw-1.0\examples\BlinkyLED\design.modus) 
*      and replicate P0[3] configuration on P13[7]. 
*      Give this pin the alias "LED_RED". Disable P0[3].
*   3. Perform "make clean"
*   4. Build and Program the device with "make DEVICE=CY8C624ABZI-D44 program"
*      Note that depending on the method used to program the device, you may 
*      need to manually reset it by pressing the SW1 RESET button on the kit.
*   4. Observe the red blinking LED.
*   5. To switch back to CY8CKIT-062-BLE or CY8CKIT-062-WIFI-BT, 
*      perform steps 1 through 3 to reconfigure the "LED_RED" to P0[3]. 
*      Then use "make program".
*
********************************************************************************
* \copyright
* Copyright 2017-2019 Cypress Semiconductor Corporation
* SPDX-License-Identifier: Apache-2.0
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*******************************************************************************/


#include "cy_device_headers.h"
#include "cycfg.h"
#include "cy_pdl.h"
#include <stdio.h>


cy_stc_scb_uart_context_t UART_HOST_context;
void UART_HOST_Interrupt(void)
{
	Cy_SCB_UART_Interrupt(UART_HOST_HW, &UART_HOST_context);
}
const cy_stc_sysint_t UART_HOST_SCB_IRQ_cfg = {
    .intrSrc = (IRQn_Type)UART_HOST_IRQ,
    .intrPriority = 7
};

int main(void)
{
    /* Set up the device based on configurator selections */
    init_cycfg_all();

    __enable_irq();
    cy_en_sysint_status_t sysint_status = CY_SYSINT_BAD_PARAM;

	sysint_status = Cy_SysInt_Init(&UART_HOST_SCB_IRQ_cfg, &UART_HOST_Interrupt);             //this sets up the interrupt for the output UART
	if(sysint_status != CY_SYSINT_SUCCESS)
	{
		printf("error Cy_SysInt_Init UART_HOST_SCB_IRQ_cfg \r\n");
		while(1);

	}
	NVIC_EnableIRQ((IRQn_Type) UART_HOST_SCB_IRQ_cfg.intrSrc);

    Cy_SCB_UART_Init(UART_HOST_HW, &UART_HOST_config, &UART_HOST_context);
    Cy_SCB_UART_Enable(UART_HOST_HW);

    printf("test PWMS \r\n");

	cy_en_tcpwm_status_t status = CY_TCPWM_BAD_PARAM ;
	status = Cy_TCPWM_PWM_Init(TCPWM_0_HW, TCPWM_0_NUM, &TCPWM_0_config);
	if(status!=CY_TCPWM_SUCCESS ){ printf("fail on TCPWM 0 \r\n"); }
	status = Cy_TCPWM_PWM_Init(TCPWM_1_HW, TCPWM_1_NUM, &TCPWM_1_config);
	if(status!=CY_TCPWM_SUCCESS ){ printf("fail on TCPWM 1 \r\n"); }
	status = Cy_TCPWM_PWM_Init(TCPWM_2_HW, TCPWM_2_NUM, &TCPWM_2_config);
	if(status!=CY_TCPWM_SUCCESS ){ printf("fail on TCPWM 2 \r\n"); }
	status = Cy_TCPWM_PWM_Init(TCPWM_3_HW, TCPWM_3_NUM, &TCPWM_3_config);
	if(status!=CY_TCPWM_SUCCESS ){ printf("fail on TCPWM 3 \r\n"); }
	status = Cy_TCPWM_PWM_Init(TCPWM_4_HW, TCPWM_4_NUM, &TCPWM_4_config);
	if(status!=CY_TCPWM_SUCCESS ){ printf("fail on TCPWM 4 \r\n"); }
	status = Cy_TCPWM_PWM_Init(TCPWM_5_HW, TCPWM_5_NUM, &TCPWM_5_config);
	if(status!=CY_TCPWM_SUCCESS ){ printf("fail on TCPWM 5 \r\n"); }
	status = Cy_TCPWM_PWM_Init(TCPWM_6_HW, TCPWM_6_NUM, &TCPWM_6_config);
	if(status!=CY_TCPWM_SUCCESS ){ printf("fail on TCPWM 6 \r\n"); }
	status = Cy_TCPWM_PWM_Init(TCPWM_7_HW, TCPWM_7_NUM, &TCPWM_7_config);
	if(status!=CY_TCPWM_SUCCESS ){ printf("fail on TCPWM 7 \r\n"); }
	status = Cy_TCPWM_PWM_Init(TCPWM_8_HW, TCPWM_8_NUM, &TCPWM_8_config);
	if(status!=CY_TCPWM_SUCCESS ){ printf("fail on TCPWM 8 \r\n"); }
	status = Cy_TCPWM_PWM_Init(TCPWM_9_HW, TCPWM_9_NUM, &TCPWM_9_config);
	if(status!=CY_TCPWM_SUCCESS ){ printf("fail on TCPWM 9 \r\n"); }
	status = Cy_TCPWM_PWM_Init(TCPWM_10_HW, TCPWM_10_NUM, &TCPWM_10_config);
	if(status!=CY_TCPWM_SUCCESS ){ printf("fail on TCPWM 10 \r\n"); }
	status = Cy_TCPWM_PWM_Init(TCPWM_11_HW, TCPWM_11_NUM, &TCPWM_11_config);
	if(status!=CY_TCPWM_SUCCESS ){ printf("fail on TCPWM 11 \r\n"); }
	status = Cy_TCPWM_PWM_Init(TCPWM_12_HW, TCPWM_12_NUM, &TCPWM_12_config);
	if(status!=CY_TCPWM_SUCCESS ){ printf("fail on TCPWM 12 \r\n"); }
	status = Cy_TCPWM_PWM_Init(TCPWM_13_HW, TCPWM_13_NUM, &TCPWM_13_config);
	if(status!=CY_TCPWM_SUCCESS ){ printf("fail on TCPWM 13 \r\n"); }
	status = Cy_TCPWM_PWM_Init(TCPWM_14_HW, TCPWM_14_NUM, &TCPWM_14_config);
	if(status!=CY_TCPWM_SUCCESS ){ printf("fail on TCPWM 14 \r\n"); }
	status = Cy_TCPWM_PWM_Init(TCPWM_15_HW, TCPWM_15_NUM, &TCPWM_15_config);
	if(status!=CY_TCPWM_SUCCESS ){ printf("fail on TCPWM 15 \r\n"); }
	status = Cy_TCPWM_PWM_Init(TCPWM_16_HW, TCPWM_16_NUM, &TCPWM_16_config);
	if(status!=CY_TCPWM_SUCCESS ){ printf("fail on TCPWM 16 \r\n"); }
	status = Cy_TCPWM_PWM_Init(TCPWM_17_HW, TCPWM_17_NUM, &TCPWM_17_config);
	if(status!=CY_TCPWM_SUCCESS ){ printf("fail on TCPWM 17 \r\n"); }
	status = Cy_TCPWM_PWM_Init(TCPWM_18_HW, TCPWM_18_NUM, &TCPWM_18_config);
	if(status!=CY_TCPWM_SUCCESS ){ printf("fail on TCPWM 18 \r\n"); }
	status = Cy_TCPWM_PWM_Init(TCPWM_19_HW, TCPWM_19_NUM, &TCPWM_19_config);
	if(status!=CY_TCPWM_SUCCESS ){ printf("fail on TCPWM 19 \r\n"); }
	status = Cy_TCPWM_PWM_Init(TCPWM_20_HW, TCPWM_20_NUM, &TCPWM_20_config);
	if(status!=CY_TCPWM_SUCCESS ){ printf("fail on TCPWM 20 \r\n"); }
	status = Cy_TCPWM_PWM_Init(TCPWM_21_HW, TCPWM_21_NUM, &TCPWM_21_config);
	if(status!=CY_TCPWM_SUCCESS ){ printf("fail on TCPWM 21 \r\n"); }
	status = Cy_TCPWM_PWM_Init(TCPWM_22_HW, TCPWM_22_NUM, &TCPWM_22_config);
	if(status!=CY_TCPWM_SUCCESS ){ printf("fail on TCPWM 22 \r\n"); }
	status = Cy_TCPWM_PWM_Init(TCPWM_23_HW, TCPWM_23_NUM, &TCPWM_23_config);
	if(status!=CY_TCPWM_SUCCESS ){ printf("fail on TCPWM 23 \r\n"); }

	Cy_SysLib_Delay(1000);

	for(int i=0; i<24; i++)
	{
		Cy_TCPWM_PWM_Enable(TCPWM_0_HW, i);
		//Cy_TCPWM_TriggerStart(TCPWM_0_HW, i);
	}
	Cy_SysLib_Delay(1000);

	uint32_t pwm_status = 0;
	for(int i=0; i<24; i++)
	{
		pwm_status = Cy_TCPWM_PWM_GetStatus(TCPWM_1_HW, i);
		printf("status of %i is 0x%08X \r\n", i, (int) pwm_status);
	}

	printf("\r\n");
	while(1)
	{

	}



    for(;;)
    {
    }
}
